@@ -3,6 +3,6 @@
 
 # imports.
 from r3sponse.classes.config import version
-from r3sponse.classes.r3sponse import r3sponse
+from r3sponse.classes.r3sponse import r3sponse, ResponseObject
 from r3sponse.classes.utils import symbol, color
 
