@@ -398,7 +398,6 @@ class ResponseObject(object):
 				sys.tracebacklimit = -1 ; sys.traceback_limit = -1
 			if error.lower() in ["valueerror"]: raise Exception(self["error"])
 			else: raise Exception(self["error"])
-	# unpack attribute(s).
 	def unpack(self, 
 		# the key / keys / defaults parameter (#1).
 		# str instance:
@@ -410,18 +409,24 @@ class ResponseObject(object):
 		keys,
 	):
 		defaults = {}
-		if isinstance(keys, dict):
-			defaults = dict(keys)
-			keys = list(keys.keys())
+		if isinstance(keys, (dict, Files.Dictionary)):
+			if isinstance(keys, dict):
+				defaults = dict(keys)
+				keys = list(keys.keys())
+			else:
+				defaults = keys.dict()
+				keys = keys.keys()
 		elif isinstance(keys, str):
 			keys = [keys]
 		unpacked = []
 		for key in keys:
-			value = None
-			try: value = self[key]
+			value, set = None, False
+			try: 
+				value = self[key]
+				set = True
 			except KeyError: value = defaults[key]
-			if value == None:
-				raise exceptions.UnpackError(f"Dictionary does not contain attribute [{key}].")
+			if not set:
+				raise exceptions.UnpackError(f"{self.instance()} does not contain attribute [{key}].")
 			unpacked.append(value)
 		return unpacked
 	def remove(self, keys=[], values=[], save=False):
